#
# spec file for package gnome-robots
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-robots
Version:        40.0
Release:        bp156.3.7
Summary:        Robots Game for GNOME
License:        GPL-3.0-or-later
Group:          Amusements/Games/Action/Arcade
URL:            https://live.gnome.org/Robots
Source0:        https://download.gnome.org/sources/gnome-robots/40/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gnome-games-scripts
BuildRequires:  itstool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gio-2.0) >= 2.32
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gsound) >= 1.0.2
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(libgnome-games-support-1) >= 1.7.1
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.36.2

%description
Robots is a graphical version of the original text based robots game,
which can be found on a number of UNIX systems. The player must outwit
the robots chasing him/her by getting them to run into each other.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}/%{_prefix}

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/org.gnome.Robots.desktop
%{_datadir}/dbus-1/services/org.gnome.Robots.service
%{_datadir}/glib-2.0/schemas/org.gnome.Robots.gschema.xml
%{_datadir}/icons/hicolor/
%{_datadir}/metainfo/org.gnome.Robots.appdata.xml
%{_mandir}/man6/%{name}.6%{?ext_man}
%{_bindir}/%{name}

%files lang -f %{name}.lang

%changelog
* Sun Mar 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.beta:
  + Fix a lookup of a game config.
  + Updated translations.
- Remove 15.patch: contained in upstream.
* Fri Jan 15 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Rewrite in Vala.
  + Updated translations.
- Add vala BuildRequires: new dependency.
- Drop "Requires(pre): pwdutils": it's been a while that we did not
  create a user for gnome-games.
- Add 15.patch: Fix crash on startup.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + Fix icon in scores dialog.
- Changes from version 3.37.3:
  + New app icon.
- Changes from verssion 3.37.2:
  + Begin preparing for GTK 4.
  + Updated translations.
* Thu Mar 26 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Fix missing translation of game type in scores dialog.
  + Updated translations.
* Fri Mar  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.3:
  + Fix non-modal preferences dialog.
  + Updated user help.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun Jan  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Fix various keyboard shortcuts.
  + Properly handle multiple activations.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Fri Sep  6 2019 qkzhu@suse.com
- Update to version 3.33.90:
  + Switch from libcanberra-gtk to gsound.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Feb 19 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.90:
  + Switch to meson build system.
  + Rename app ID to org.gnome.Robots.
  + Updated translations.
- Drop glib2_gsettings_schema_requires and post(un) handling of
  glib2_gsettings_schema_post(un), desktop_database_post(un) and
  icon_theme_cache_post()un), no longer needed.
- Add fdupes BuildRequires and macros.
- Drop obsolete hicolor-icon-theme, intltool, update-desktop-files
  and yelp-tools BuildRequires: No longer needed.
- Add itstool and meson BuildRequires: Switch to meson build system
  and add corresponding macros.
- Add explicit pkgconfig(gio-2.0) BuildRequires: Align with what
  meson checks for.
- Drop gnobots2 and gnobots2-lang Obsoletes, no current openSUSE
  release have shipped any of those packages.
* Fri Jan  4 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Replace app menu with window menu.
  + Updated translations.
* Sun Mar 11 2018 dimstar@opensuse.org
- Update to version 3.22.3:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Sep  9 2017 dimstar@opensuse.org
- Update to version 3.22.2:
  + Updated translations.
* Fri Nov 11 2016 dimstar@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Mon Aug 29 2016 dimstar@opensuse.org
- Update to version 3.21.91:
  + Build with even newer libgnome-games-support.
  + Updated translations.
- Replace pkgconfig(libgnome-games-support-1.0) BuildRequires with
  pkgconfig(libgnome-games-support-1), following upstream changes.
* Tue Aug 16 2016 dimstar@opensuse.org
- Update to version 3.21.90:
  + Build with new libgnome-games-support.
  + Updated translations.
- Replace pkgconfig(libgames-support-1.0) BuildRequires
  pkgconfig(libgnome-games-support-1.0), following upstreams port.
* Sat May  7 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Updated translations.
* Fri Apr  8 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0.1:
  + Version number bump after mis-tagging 3.20.0.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + License change: now licensed as GPLv3+.
  + New dependency: libgames-support.
  + New scores dialog via libgames-support.
  + Updated translations.
- Add pkgconfig(libgames-support-1.0) BuildRequires: new
  dependency.
- Change License tag to GPL-3.0+, following upstreams change.
* Fri Nov  6 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Mon Sep 14 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Fix dragging the window after clicking the game view.
  + Fix critical on game shutdown.
  + Updated translations.
* Thu Aug 13 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Set correct icon for ghost in user help.
  + Fix description text for low-risk UFO in user help.
  + Updated translations.
* Sat May 23 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Add new player death sound.
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Provide symbolic app icon.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Use gresource, other code improvements.
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Improved user help.
  + Updated translations.
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Updated translations.
* Fri Oct 10 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Mon Sep 22 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated appdata.
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Fix whitespace error in SVG icon.
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Updated translations.
- No longer do special things for permissions: the reason we had
  this ws for the shared highscore lists stored in /var. This in
  turn has no longer happened since 3.11.90.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Remove accidental dependency on system menu.h introduced in
    3.13.3.
  + Updated translations.
- Drop gnome-robots-includes.patch: fixed upstream.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Safe Teleport is now disabled when no safe teleports are
    remaining.
  + Add app menu and header bar.
  + Remove menu bar, toolbar, and status bar.
  + Remove fullscreen.
  + New default hotkeys that do not require number pad.
  + Updated help.
- Add gnome-robots-includes.patch: Fix build after the change from
  MenuBars to App Menus by upstream.
* Mon Jun 30 2014 zaitor@opensuse.org
- Update to version 3.12.3:
  + Fix default theme name so that correct theme is shown in
    preferences dialog.
  + Fix Restore Defaults button in keyboard section of preferences
    dialog.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated help.
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Prohibit super safe moves without safe moves.
  + Updated translations.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.90:
  + Store scores in home directory.
  + Add Mallard help.
  + Appdata: specify project_group.
  + Rename desktop file to gnome-robots.desktop.
* Wed Feb  5 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + Fix scores system.
  + Updated translations.
* Wed Feb  5 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Require intltool 0.50.
  + Remove BugBuddy support.
  + Update AppData.
  + Updated translations.
* Wed Feb  5 2014 zaitor@opensuse.org
- Update to version 3.10.2:
  + The game no longer restarts upon entering the preferences
    dialog.
  + Updated translations.
- Changes from version 3.10.1:
  + Fix scores system.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 23 2013 idonmez@suse.com
- Create games user/group on demand (fate#314560)
  + Depend on pwdutils for that to work.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Add appdata file.
* Wed Aug 21 2013 zaitor@opensuse.org
- Update to version 3.9.90:
  + Set prgname so WM_CLASS matches the desktop file.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Rename the desktop file back to gnobots2.desktop.
  + Move themes in from gnome-games-extra-data.
  + Add high contrast icons.
  + Updated translations.
- Also obsolete gnobots2-lang to ease upgrades.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.90: split-off from gnome-games.
